(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
    typeof define === 'function' && define.amd ? define(['exports'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.bistring = {}));
})(this, (function (exports) { 'use strict';

    /*!
     * Copyright (c) Microsoft Corporation. All rights reserved.
     * Licensed under the MIT license.
     */
    class Alignment {
      constructor(values) {
        const copy = [];

        for (const [o, m] of values) {
          if (copy.length > 0) {
            const [oPrev, mPrev] = copy[copy.length - 1];

            if (o < oPrev) {
              throw new Error("Original sequence position moved backwards");
            } else if (m < mPrev) {
              throw new Error("Modified sequence position moved backwards");
            } else if (o === oPrev && m === mPrev) {
              continue;
            }
          }

          copy.push(Object.freeze([o, m]));
        }

        if (copy.length === 0) {
          throw new Error("No sequence positions to align");
        }

        this.values = Object.freeze(copy);
        this.length = copy.length;
        Object.freeze(this);
      }

      static identity(start, end) {
        if (typeof start !== "number") {
          end = start[1];
          start = start[0];
        }

        if (end === undefined) {
          end = start;
          start = 0;
        }

        const values = [];

        for (let i = start; i <= end; ++i) {
          values.push([i, i]);
        }

        return new Alignment(values);
      }

      static infer(original, modified, costFn) {
        if (costFn === undefined) {
          costFn = (o, m) => Number(o !== m);
        }

        let oArray = original instanceof Array ? original : Array.from(original);
        let mArray = modified instanceof Array ? modified : Array.from(modified);

        if (oArray.length < mArray.length) {
          let result = this._inferRecursive(mArray, oArray, (m, o) => costFn(o, m));

          return new Alignment(result).inverse();
        } else {
          let result = this._inferRecursive(oArray, mArray, costFn);

          return new Alignment(result);
        }
      }

      static _inferRecursive(original, modified, costFn) {
        if (original.length <= 1 || modified.length <= 1) {
          return this._inferMatrix(original, modified, costFn);
        }

        const oMid = original.length >> 1;
        const oLeft = original.slice(0, oMid);
        const oRight = original.slice(oMid);

        const lCosts = this._inferCosts(oLeft, modified, costFn);

        const oRightRev = oRight.slice();
        oRightRev.reverse();
        const modifiedRev = modified.slice();
        modifiedRev.reverse();

        const rCosts = this._inferCosts(oRightRev, modifiedRev, costFn);

        rCosts.reverse();
        let mMid = -1,
            best = Infinity;

        for (let i = 0; i < lCosts.length; ++i) {
          const score = lCosts[i] + rCosts[i];

          if (score < best) {
            mMid = i;
            best = score;
          }
        }

        const mLeft = modified.slice(0, mMid);
        const mRight = modified.slice(mMid);

        const left = this._inferRecursive(oLeft, mLeft, costFn);

        const right = this._inferRecursive(oRight, mRight, costFn);

        for (const [o, m] of right) {
          left.push([o + oMid, m + mMid]);
        }

        return left;
      }

      static _inferCosts(original, modified, costFn) {
        let row = [0];

        for (let i = 0; i < modified.length; ++i) {
          const cost = row[i] + costFn(undefined, modified[i]);
          row.push(cost);
        }

        let prev = Array(row.length);
        prev.fill(0);

        for (const o of original) {
          [prev, row] = [row, prev];
          row[0] = prev[0] + costFn(o, undefined);

          for (let i = 0; i < modified.length; ++i) {
            const m = modified[i];
            const subCost = prev[i] + costFn(o, m);
            const delCost = prev[i + 1] + costFn(o, undefined);
            const insCost = row[i] + costFn(undefined, m);
            row[i + 1] = Math.min(subCost, delCost, insCost);
          }
        }

        return row;
      }

      static _inferMatrix(original, modified, costFn) {
        const row = [{
          cost: 0,
          i: -1,
          j: -1
        }];

        for (let j = 0; j < modified.length; ++j) {
          const m = modified[j];
          row.push({
            cost: row[j].cost + costFn(undefined, m),
            i: 0,
            j: j
          });
        }

        const matrix = [row];

        for (let i = 0; i < original.length; ++i) {
          const o = original[i];
          const prev = matrix[i];
          const row = [{
            cost: prev[0].cost + costFn(o, undefined),
            i: i,
            j: 0
          }];

          for (let j = 0; j < modified.length; ++j) {
            const m = modified[j];
            let cost = prev[j].cost + costFn(o, m);
            let x = i,
                y = j;
            const delCost = prev[j + 1].cost + costFn(o, undefined);

            if (delCost < cost) {
              cost = delCost;
              x = i;
              y = j + 1;
            }

            const insCost = row[j].cost + costFn(undefined, m);

            if (insCost < cost) {
              cost = insCost;
              x = i + 1;
              y = j;
            }

            row.push({
              cost: cost,
              i: x,
              j: y
            });
          }

          matrix.push(row);
        }

        const result = [];
        let i = matrix.length - 1;
        let j = matrix[i].length - 1;

        while (i >= 0) {
          result.push([i, j]);
          ({
            i,
            j
          } = matrix[i][j]);
        }

        result.reverse();
        return result;
      }

      slice(start, end) {
        return new Alignment(this.values.slice(start, end));
      }

      _search(which, start, end) {
        let first = 0,
            limit = this.length;

        while (first < limit) {
          const mid = first + (limit - first >> 2);

          if (this.values[mid][which] <= start) {
            first = mid + 1;
          } else {
            limit = mid;
          }
        }

        if (first === 0) {
          throw new RangeError("Start index too small");
        }

        --first;
        let last = first;
        limit = this.length;

        while (last < limit) {
          const mid = last + (limit - last >> 2);

          if (this.values[mid][which] < end) {
            last = mid + 1;
          } else {
            limit = mid;
          }
        }

        if (last === this.length) {
          throw new RangeError("End index too large");
        }

        return [first, last];
      }

      _bounds(which, start, end) {
        if (start === undefined) {
          return [this.values[0][1 - which], this.values[this.length - 1][1 - which]];
        } else if (typeof start !== "number") {
          end = start[1];
          start = start[0];
        }

        if (end === undefined) {
          end = this.values[this.length - 1][which];
        }

        const [first, last] = this._search(which, start, end);

        return [this.values[first][1 - which], this.values[last][1 - which]];
      }

      originalBounds(start, end) {
        return this._bounds(1, start, end);
      }

      modifiedBounds(start, end) {
        return this._bounds(0, start, end);
      }

      _sliceBy(which, start, end) {
        if (typeof start !== "number") {
          end = start[1];
          start = start[0];
        }

        if (end === undefined) {
          end = this.values[this.length - 1][which];
        }

        const [first, last] = this._search(which, start, end);

        const values = this.values.slice(first, last + 1);

        for (const i in values) {
          const v = values[i].slice();
          v[which] = Math.max(start, Math.min(v[which], end));
          values[i] = v;
        }

        return new Alignment(values);
      }

      sliceByOriginal(start, end) {
        return this._sliceBy(0, start, end);
      }

      sliceByModified(start, end) {
        return this._sliceBy(1, start, end);
      }

      shift(deltaO, deltaM) {
        const shifted = this.values.map(_ref => {
          let [o, m] = _ref;
          return [o + deltaO, m + deltaM];
        });
        return new Alignment(shifted);
      }

      concat() {
        const values = this.values.slice();

        for (var _len = arguments.length, others = new Array(_len), _key = 0; _key < _len; _key++) {
          others[_key] = arguments[_key];
        }

        for (const other of others) {
          values.push(...other.values);
        }

        return new Alignment(values);
      }

      compose(other) {
        const [mf, ml] = this.modifiedBounds();
        const [of, ol] = other.originalBounds();

        if (mf !== of || ml !== ol) {
          throw new RangeError("Incompatible alignments");
        }

        const values = [];
        let i = 0,
            iMax = this.length;
        let j = 0,
            jMax = other.length;

        while (i < iMax) {
          while (this.values[i][1] > other.values[j][0]) {
            ++j;
          }

          while (this.values[i][1] < other.values[j][0] && this.values[i + 1][1] <= other.values[j][0]) {
            ++i;
          }

          values.push([this.values[i][0], other.values[j][1]]);

          while (i + 1 < iMax && this.values[i][0] === this.values[i + 1][0]) {
            ++i;
          }

          let needsUpper = false;

          while (j + 1 < jMax && this.values[i][1] >= other.values[j + 1][0]) {
            needsUpper = true;
            ++j;
          }

          if (needsUpper) {
            values.push([this.values[i][0], other.values[j][1]]);
          }

          ++i;
        }

        return new Alignment(values);
      }

      inverse() {
        return new Alignment(this.values.map(_ref2 => {
          let [o, m] = _ref2;
          return [m, o];
        }));
      }

      equals(other) {
        if (this.length != other.length) {
          return false;
        }

        for (let i = 0; i < this.length; ++i) {
          const [to, tm] = this.values[i];
          const [oo, om] = other.values[i];

          if (to != oo || tm != om) {
            return false;
          }
        }

        return true;
      }

    }

    /*!
     * Copyright (c) Microsoft Corporation. All rights reserved.
     * Licensed under the MIT license.
     */
    function expandReplacement(replacement, match) {
      const index = match.index;
      const input = match.input;
      let result = "";

      for (let i = 0; i < replacement.length; ++i) {
        const c = replacement[i];

        if (c === "$" && i + 1 < replacement.length) {
          let n = replacement[++i];

          switch (n) {
            case "$":
              result += "$";
              continue;

            case "&":
              result += match[0];
              continue;

            case "`":
              result += input.slice(0, index);
              continue;

            case "'":
              result += input.slice(index + match[0].length);
              continue;
          }

          if ("0123456789".includes(n)) {
            const n2 = replacement[i + 1];

            if ("0123456789".includes(n2)) {
              n += n2;
              ++i;
            }

            const index = parseInt(n, 10);

            if (index >= 1 && index < match.length) {
              result += match[index];
              continue;
            }
          }

          result += c + n;
        } else {
          result += c;
        }
      }

      return result;
    }

    function normalizeReplacer(replacement) {
      if (typeof replacement === "string") {
        return match => expandReplacement(replacement, match);
      } else {
        const replacer = replacement;
        return match => replacer(...match, match.index, match.input);
      }
    }
    function isStatefulRegExp(regexp) {
      return regexp.global || regexp.sticky;
    }
    function cloneRegExp(regexp) {
      let addFlags = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : "";
      let removeFlags = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : "";
      let flags = "";

      for (const flag of regexp.flags) {
        if (!removeFlags.includes(flag)) {
          flags += flag;
        }
      }

      for (const flag of addFlags) {
        if (!flags.includes(flag)) {
          flags += flag;
        }
      }

      return new RegExp(regexp.source, flags);
    }

    /*!
     * Copyright (c) Microsoft Corporation. All rights reserved.
     * Licensed under the MIT license.
     */
    class BiStringBuilder {
      constructor(original) {
        this._original = BiString.from(original);
        this._modified = [];
        this._alignment = [[0, 0]];
        this._oPos = 0;
        this._mPos = 0;
      }

      get original() {
        return this._original.original;
      }

      get current() {
        return this._original.modified;
      }

      get modified() {
        return this._modified.join("");
      }

      get alignment() {
        return new Alignment(this._alignment);
      }

      get position() {
        return this._oPos;
      }

      get remaining() {
        return this.current.length - this.position;
      }

      get isComplete() {
        return this.remaining === 0;
      }

      peek(n) {
        return this.current.slice(this._oPos, this._oPos + n);
      }

      _advance(oCount, mCount) {
        this._oPos += oCount;
        this._mPos += mCount;

        if (oCount > 0 || mCount > 0) {
          this._alignment.push([this._oPos, this._mPos]);
        }
      }

      skip(n) {
        if (n > 0) {
          this._modified.push(this.peek(n));

          for (let i = 0; i < n; ++i) {
            this._advance(1, 1);
          }
        }
      }

      skipRest() {
        this.skip(this.remaining);
      }

      insert(str) {
        this.replace(0, str);
      }

      discard(n) {
        this.replace(n, "");
      }

      discardRest() {
        this.discard(this.remaining);
      }

      replace(n, str) {
        if (typeof str === "string") {
          if (str.length > 0) {
            this._modified.push(str);
          }

          this._advance(n, str.length);
        } else {
          if (str.original !== this.peek(n)) {
            throw new Error("BiString doesn't match the current string");
          }

          this._modified.push(str.modified);

          const alignment = str.alignment.values;

          for (let i = 1; i < alignment.length; ++i) {
            const [o0, m0] = alignment[i - 1];
            const [o1, m1] = alignment[i];

            this._advance(o1 - o0, m1 - m0);
          }
        }
      }

      append(bs) {
        this.replace(bs.original.length, bs);
      }

      _match(pattern) {
        if (!isStatefulRegExp(pattern)) {
          pattern = cloneRegExp(pattern, "g");
        }

        pattern.lastIndex = this.position;
        return pattern.exec(this.current);
      }

      *_matchAll(pattern) {
        if (pattern.global) {
          pattern.lastIndex = this.position;
          let match;

          while (match = pattern.exec(this.current)) {
            yield match;
          }
        } else {
          if (!pattern.sticky) {
            pattern = cloneRegExp(pattern, "g");
          }

          pattern.lastIndex = this.position;
          let match;

          if (match = pattern.exec(this.current)) {
            yield match;
          }
        }
      }

      skipMatch(pattern) {
        if (this._match(pattern)) {
          this.skip(pattern.lastIndex - this.position);
          return true;
        } else {
          return false;
        }
      }

      discardMatch(pattern) {
        const match = this._match(pattern);

        if (match) {
          this.skip(match.index - this.position);
          this.discard(match[0].length);
          return true;
        } else {
          return false;
        }
      }

      replaceMatch(pattern, replacement) {
        const replacer = normalizeReplacer(replacement);

        const match = this._match(pattern);

        if (match) {
          this.skip(match.index - this.position);
          this.replace(match[0].length, replacer(match));
          return true;
        } else {
          return false;
        }
      }

      replaceAll(pattern, replacement) {
        const replacer = normalizeReplacer(replacement);

        for (const match of this._matchAll(pattern)) {
          this.skip(match.index - this.position);
          this.replace(match[0].length, replacer(match));
        }

        this.skipRest();
      }

      build() {
        if (!this.isComplete) {
          throw new Error(`The string is not completely built yet (${this.remaining} characters remaining)`);
        }

        const alignment = this._original.alignment.compose(this.alignment);

        return new BiString(this.original, this.modified, alignment);
      }

      rewind() {
        this._original = this.build();
        this._modified = [];
        this._alignment = [[0, 0]];
        this._oPos = 0;
        this._mPos = 0;
      }

    }

    const CATEGORIES = ["Lu", "Ll", "Lt", "Lm", "Lo", "Mn", "Mc", "Me", "Nd", "Nl", "No", "Pc", "Pd", "Ps", "Pe", "Pi", "Pf", "Po", "Sm", "Sc", "Sk", "So", "Zs", "Zl", "Zp", "Cc", "Cf", "Cs", "Co", "Cn"];
    const CATEGORY_REGEXP = /(\p{Lu})|(\p{Ll})|(\p{Lt})|(\p{Lm})|(\p{Lo})|(\p{Mn})|(\p{Mc})|(\p{Me})|(\p{Nd})|(\p{Nl})|(\p{No})|(\p{Pc})|(\p{Pd})|(\p{Ps})|(\p{Pe})|(\p{Pi})|(\p{Pf})|(\p{Po})|(\p{Sm})|(\p{Sc})|(\p{Sk})|(\p{So})|(\p{Zs})|(\p{Zl})|(\p{Zp})|(\p{Cc})|(\p{Cf})|(\p{Cs})|(\p{Co})|(\p{Cn})/u;

    function category(cp) {
      const match = cp.match(CATEGORY_REGEXP);
      const index = match.indexOf(cp, 1) - 1;
      return CATEGORIES[index];
    }

    class AugmentedGlyph {
      constructor(original, normalized, upper) {
        this.original = original;
        this.normalized = normalized;
        this.upper = upper;
        this.root = String.fromCodePoint(upper.codePointAt(0));
        this.category = category(this.root);
        this.topCategory = this.category[0];
      }

      static costFn(a, b) {
        if (!a || !b) {
          return 4;
        }

        let result = 0;
        result += +(a.original !== b.original);
        result += +(a.normalized !== b.normalized);
        result += +(a.upper !== b.upper);
        result += +(a.root !== b.root);
        result += +(a.category !== b.topCategory);
        result += +(a.topCategory !== b.topCategory);
        return result;
      }

    }

    const GLYPH_REGEXP = /\P{M}\p{M}*|^\p{M}+/gu;

    class AugmentedString {
      constructor(original) {
        const normalized = new BiString(original).normalize("NFKD");
        const upper = new BiString(normalized.modified).toUpperCase();
        const glyphs = [];
        const alignment = [[0, 0]];

        for (const match of upper.matchAll(GLYPH_REGEXP)) {
          const [o, m] = alignment[alignment.length - 1];
          const upperC = match[0];
          const normBounds = upper.alignment.originalBounds(o, o + upperC.length);
          const normC = upper.original.slice(...normBounds);
          const origBounds = normalized.alignment.originalBounds(normBounds);
          const origC = normalized.original.slice(...origBounds);
          glyphs.push(new AugmentedGlyph(origC, normC, upperC));
          alignment.push([o + normC.length, m + 1]);
        }

        this.original = original;
        this.glyphs = glyphs;
        this.alignment = normalized.alignment.compose(new Alignment(alignment));
      }

    }

    function heuristicInfer(original, modified) {
      const augOrig = new AugmentedString(original);
      const augMod = new AugmentedString(modified);
      let alignment = Alignment.infer(augOrig.glyphs, augMod.glyphs, AugmentedGlyph.costFn);
      alignment = augOrig.alignment.compose(alignment);
      alignment = alignment.compose(augMod.alignment.inverse());
      return new BiString(original, modified, alignment);
    }

    const NFC_CHUNK = /.[\u0300-\u034e\u0350-\u036f\u0483-\u0487\u0591-\u05bd\u05bf\u05c1-\u05c2\u05c4-\u05c5\u05c7\u0610-\u061a\u064b-\u065f\u0670\u06d6-\u06dc\u06df-\u06e4\u06e7-\u06e8\u06ea-\u06ed\u0711\u0730-\u074a\u07eb-\u07f3\u07fd\u0816-\u0819\u081b-\u0823\u0825-\u0827\u0829-\u082d\u0859-\u085b\u08d3-\u08e1\u08e3-\u08ff\u093c\u094d\u0951-\u0954\u09bc\u09be\u09cd\u09d7\u09fe\u0a3c\u0a4d\u0abc\u0acd\u0b3c\u0b3e\u0b4d\u0b56-\u0b57\u0bbe\u0bcd\u0bd7\u0c4d\u0c55-\u0c56\u0cbc\u0cc2\u0ccd\u0cd5-\u0cd6\u0d3b-\u0d3c\u0d3e\u0d4d\u0d57\u0dca\u0dcf\u0ddf\u0e38-\u0e3a\u0e48-\u0e4b\u0eb8-\u0eba\u0ec8-\u0ecb\u0f18-\u0f19\u0f35\u0f37\u0f39\u0f71-\u0f75\u0f7a-\u0f7d\u0f80-\u0f84\u0f86-\u0f87\u0fc6\u102e\u1037\u1039-\u103a\u108d\u1161-\u1175\u11a8-\u11c2\u135d-\u135f\u1714\u1734\u17d2\u17dd\u18a9\u1939-\u193b\u1a17-\u1a18\u1a60\u1a75-\u1a7c\u1a7f\u1ab0-\u1abd\u1b34-\u1b35\u1b44\u1b6b-\u1b73\u1baa-\u1bab\u1be6\u1bf2-\u1bf3\u1c37\u1cd0-\u1cd2\u1cd4-\u1ce0\u1ce2-\u1ce8\u1ced\u1cf4\u1cf8-\u1cf9\u1dc0-\u1df9\u1dfb-\u1dff\u20d0-\u20dc\u20e1\u20e5-\u20f0\u2cef-\u2cf1\u2d7f\u2de0-\u2dff\u302a-\u302f\u3099-\u309a\ua66f\ua674-\ua67d\ua69e-\ua69f\ua6f0-\ua6f1\ua806\ua8c4\ua8e0-\ua8f1\ua92b-\ua92d\ua953\ua9b3\ua9c0\uaab0\uaab2-\uaab4\uaab7-\uaab8\uaabe-\uaabf\uaac1\uaaf6\uabed\ufb1e\ufe20-\ufe2f\u{101fd}\u{102e0}\u{10376}-\u{1037a}\u{10a0d}\u{10a0f}\u{10a38}-\u{10a3a}\u{10a3f}\u{10ae5}-\u{10ae6}\u{10d24}-\u{10d27}\u{10f46}-\u{10f50}\u{11046}\u{1107f}\u{110b9}-\u{110ba}\u{11100}-\u{11102}\u{11127}\u{11133}-\u{11134}\u{11173}\u{111c0}\u{111ca}\u{11235}-\u{11236}\u{112e9}-\u{112ea}\u{1133b}-\u{1133c}\u{1133e}\u{1134d}\u{11357}\u{11366}-\u{1136c}\u{11370}-\u{11374}\u{11442}\u{11446}\u{1145e}\u{114b0}\u{114ba}\u{114bd}\u{114c2}-\u{114c3}\u{115af}\u{115bf}-\u{115c0}\u{1163f}\u{116b6}-\u{116b7}\u{1172b}\u{11839}-\u{1183a}\u{119e0}\u{11a34}\u{11a47}\u{11a99}\u{11c3f}\u{11d42}\u{11d44}-\u{11d45}\u{11d97}\u{16af0}-\u{16af4}\u{16b30}-\u{16b36}\u{1bc9e}\u{1d165}-\u{1d169}\u{1d16d}-\u{1d172}\u{1d17b}-\u{1d182}\u{1d185}-\u{1d18b}\u{1d1aa}-\u{1d1ad}\u{1d242}-\u{1d244}\u{1e000}-\u{1e006}\u{1e008}-\u{1e018}\u{1e01b}-\u{1e021}\u{1e023}-\u{1e024}\u{1e026}-\u{1e02a}\u{1e130}-\u{1e136}\u{1e2ec}-\u{1e2ef}\u{1e8d0}-\u{1e8d6}\u{1e944}-\u{1e94a}]*/gsu;
    const NFD_CHUNK = /.[\u0300-\u034e\u0350-\u036f\u0483-\u0487\u0591-\u05bd\u05bf\u05c1-\u05c2\u05c4-\u05c5\u05c7\u0610-\u061a\u064b-\u065f\u0670\u06d6-\u06dc\u06df-\u06e4\u06e7-\u06e8\u06ea-\u06ed\u0711\u0730-\u074a\u07eb-\u07f3\u07fd\u0816-\u0819\u081b-\u0823\u0825-\u0827\u0829-\u082d\u0859-\u085b\u08d3-\u08e1\u08e3-\u08ff\u093c\u094d\u0951-\u0954\u09bc\u09cd\u09fe\u0a3c\u0a4d\u0abc\u0acd\u0b3c\u0b4d\u0bcd\u0c4d\u0c55-\u0c56\u0cbc\u0ccd\u0d3b-\u0d3c\u0d4d\u0dca\u0e38-\u0e3a\u0e48-\u0e4b\u0eb8-\u0eba\u0ec8-\u0ecb\u0f18-\u0f19\u0f35\u0f37\u0f39\u0f71-\u0f75\u0f7a-\u0f7d\u0f80-\u0f84\u0f86-\u0f87\u0fc6\u1037\u1039-\u103a\u108d\u135d-\u135f\u1714\u1734\u17d2\u17dd\u18a9\u1939-\u193b\u1a17-\u1a18\u1a60\u1a75-\u1a7c\u1a7f\u1ab0-\u1abd\u1b34\u1b44\u1b6b-\u1b73\u1baa-\u1bab\u1be6\u1bf2-\u1bf3\u1c37\u1cd0-\u1cd2\u1cd4-\u1ce0\u1ce2-\u1ce8\u1ced\u1cf4\u1cf8-\u1cf9\u1dc0-\u1df9\u1dfb-\u1dff\u20d0-\u20dc\u20e1\u20e5-\u20f0\u2cef-\u2cf1\u2d7f\u2de0-\u2dff\u302a-\u302f\u3099-\u309a\ua66f\ua674-\ua67d\ua69e-\ua69f\ua6f0-\ua6f1\ua806\ua8c4\ua8e0-\ua8f1\ua92b-\ua92d\ua953\ua9b3\ua9c0\uaab0\uaab2-\uaab4\uaab7-\uaab8\uaabe-\uaabf\uaac1\uaaf6\uabed\ufb1e\ufe20-\ufe2f\u{101fd}\u{102e0}\u{10376}-\u{1037a}\u{10a0d}\u{10a0f}\u{10a38}-\u{10a3a}\u{10a3f}\u{10ae5}-\u{10ae6}\u{10d24}-\u{10d27}\u{10f46}-\u{10f50}\u{11046}\u{1107f}\u{110b9}-\u{110ba}\u{11100}-\u{11102}\u{11133}-\u{11134}\u{11173}\u{111c0}\u{111ca}\u{11235}-\u{11236}\u{112e9}-\u{112ea}\u{1133b}-\u{1133c}\u{1134d}\u{11366}-\u{1136c}\u{11370}-\u{11374}\u{11442}\u{11446}\u{1145e}\u{114c2}-\u{114c3}\u{115bf}-\u{115c0}\u{1163f}\u{116b6}-\u{116b7}\u{1172b}\u{11839}-\u{1183a}\u{119e0}\u{11a34}\u{11a47}\u{11a99}\u{11c3f}\u{11d42}\u{11d44}-\u{11d45}\u{11d97}\u{16af0}-\u{16af4}\u{16b30}-\u{16b36}\u{1bc9e}\u{1d165}-\u{1d169}\u{1d16d}-\u{1d172}\u{1d17b}-\u{1d182}\u{1d185}-\u{1d18b}\u{1d1aa}-\u{1d1ad}\u{1d242}-\u{1d244}\u{1e000}-\u{1e006}\u{1e008}-\u{1e018}\u{1e01b}-\u{1e021}\u{1e023}-\u{1e024}\u{1e026}-\u{1e02a}\u{1e130}-\u{1e136}\u{1e2ec}-\u{1e2ef}\u{1e8d0}-\u{1e8d6}\u{1e944}-\u{1e94a}]*/gsu;
    const NFKC_CHUNK = /.[\u0300-\u034e\u0350-\u036f\u0483-\u0487\u0591-\u05bd\u05bf\u05c1-\u05c2\u05c4-\u05c5\u05c7\u0610-\u061a\u064b-\u065f\u0670\u06d6-\u06dc\u06df-\u06e4\u06e7-\u06e8\u06ea-\u06ed\u0711\u0730-\u074a\u07eb-\u07f3\u07fd\u0816-\u0819\u081b-\u0823\u0825-\u0827\u0829-\u082d\u0859-\u085b\u08d3-\u08e1\u08e3-\u08ff\u093c\u094d\u0951-\u0954\u09bc\u09be\u09cd\u09d7\u09fe\u0a3c\u0a4d\u0abc\u0acd\u0b3c\u0b3e\u0b4d\u0b56-\u0b57\u0bbe\u0bcd\u0bd7\u0c4d\u0c55-\u0c56\u0cbc\u0cc2\u0ccd\u0cd5-\u0cd6\u0d3b-\u0d3c\u0d3e\u0d4d\u0d57\u0dca\u0dcf\u0ddf\u0e38-\u0e3a\u0e48-\u0e4b\u0eb8-\u0eba\u0ec8-\u0ecb\u0f18-\u0f19\u0f35\u0f37\u0f39\u0f71-\u0f75\u0f7a-\u0f7d\u0f80-\u0f84\u0f86-\u0f87\u0fc6\u102e\u1037\u1039-\u103a\u108d\u1161-\u1175\u11a8-\u11c2\u135d-\u135f\u1714\u1734\u17d2\u17dd\u18a9\u1939-\u193b\u1a17-\u1a18\u1a60\u1a75-\u1a7c\u1a7f\u1ab0-\u1abd\u1b34-\u1b35\u1b44\u1b6b-\u1b73\u1baa-\u1bab\u1be6\u1bf2-\u1bf3\u1c37\u1cd0-\u1cd2\u1cd4-\u1ce0\u1ce2-\u1ce8\u1ced\u1cf4\u1cf8-\u1cf9\u1dc0-\u1df9\u1dfb-\u1dff\u20d0-\u20dc\u20e1\u20e5-\u20f0\u2cef-\u2cf1\u2d7f\u2de0-\u2dff\u302a-\u302f\u3099-\u309a\u3133\u3135-\u3136\u313a-\u313f\u314f-\u3163\ua66f\ua674-\ua67d\ua69e-\ua69f\ua6f0-\ua6f1\ua806\ua8c4\ua8e0-\ua8f1\ua92b-\ua92d\ua953\ua9b3\ua9c0\uaab0\uaab2-\uaab4\uaab7-\uaab8\uaabe-\uaabf\uaac1\uaaf6\uabed\ufb1e\ufe20-\ufe2f\uff9e-\uff9f\uffa3\uffa5-\uffa6\uffaa-\uffaf\uffc2-\uffc7\uffca-\uffcf\uffd2-\uffd7\uffda-\uffdc\u{101fd}\u{102e0}\u{10376}-\u{1037a}\u{10a0d}\u{10a0f}\u{10a38}-\u{10a3a}\u{10a3f}\u{10ae5}-\u{10ae6}\u{10d24}-\u{10d27}\u{10f46}-\u{10f50}\u{11046}\u{1107f}\u{110b9}-\u{110ba}\u{11100}-\u{11102}\u{11127}\u{11133}-\u{11134}\u{11173}\u{111c0}\u{111ca}\u{11235}-\u{11236}\u{112e9}-\u{112ea}\u{1133b}-\u{1133c}\u{1133e}\u{1134d}\u{11357}\u{11366}-\u{1136c}\u{11370}-\u{11374}\u{11442}\u{11446}\u{1145e}\u{114b0}\u{114ba}\u{114bd}\u{114c2}-\u{114c3}\u{115af}\u{115bf}-\u{115c0}\u{1163f}\u{116b6}-\u{116b7}\u{1172b}\u{11839}-\u{1183a}\u{119e0}\u{11a34}\u{11a47}\u{11a99}\u{11c3f}\u{11d42}\u{11d44}-\u{11d45}\u{11d97}\u{16af0}-\u{16af4}\u{16b30}-\u{16b36}\u{1bc9e}\u{1d165}-\u{1d169}\u{1d16d}-\u{1d172}\u{1d17b}-\u{1d182}\u{1d185}-\u{1d18b}\u{1d1aa}-\u{1d1ad}\u{1d242}-\u{1d244}\u{1e000}-\u{1e006}\u{1e008}-\u{1e018}\u{1e01b}-\u{1e021}\u{1e023}-\u{1e024}\u{1e026}-\u{1e02a}\u{1e130}-\u{1e136}\u{1e2ec}-\u{1e2ef}\u{1e8d0}-\u{1e8d6}\u{1e944}-\u{1e94a}]*/gsu;
    const NFKD_CHUNK = /.[\u0300-\u034e\u0350-\u036f\u0483-\u0487\u0591-\u05bd\u05bf\u05c1-\u05c2\u05c4-\u05c5\u05c7\u0610-\u061a\u064b-\u065f\u0670\u06d6-\u06dc\u06df-\u06e4\u06e7-\u06e8\u06ea-\u06ed\u0711\u0730-\u074a\u07eb-\u07f3\u07fd\u0816-\u0819\u081b-\u0823\u0825-\u0827\u0829-\u082d\u0859-\u085b\u08d3-\u08e1\u08e3-\u08ff\u093c\u094d\u0951-\u0954\u09bc\u09cd\u09fe\u0a3c\u0a4d\u0abc\u0acd\u0b3c\u0b4d\u0bcd\u0c4d\u0c55-\u0c56\u0cbc\u0ccd\u0d3b-\u0d3c\u0d4d\u0dca\u0e38-\u0e3a\u0e48-\u0e4b\u0eb8-\u0eba\u0ec8-\u0ecb\u0f18-\u0f19\u0f35\u0f37\u0f39\u0f71-\u0f75\u0f7a-\u0f7d\u0f80-\u0f84\u0f86-\u0f87\u0fc6\u1037\u1039-\u103a\u108d\u135d-\u135f\u1714\u1734\u17d2\u17dd\u18a9\u1939-\u193b\u1a17-\u1a18\u1a60\u1a75-\u1a7c\u1a7f\u1ab0-\u1abd\u1b34\u1b44\u1b6b-\u1b73\u1baa-\u1bab\u1be6\u1bf2-\u1bf3\u1c37\u1cd0-\u1cd2\u1cd4-\u1ce0\u1ce2-\u1ce8\u1ced\u1cf4\u1cf8-\u1cf9\u1dc0-\u1df9\u1dfb-\u1dff\u20d0-\u20dc\u20e1\u20e5-\u20f0\u2cef-\u2cf1\u2d7f\u2de0-\u2dff\u302a-\u302f\u3099-\u309a\ua66f\ua674-\ua67d\ua69e-\ua69f\ua6f0-\ua6f1\ua806\ua8c4\ua8e0-\ua8f1\ua92b-\ua92d\ua953\ua9b3\ua9c0\uaab0\uaab2-\uaab4\uaab7-\uaab8\uaabe-\uaabf\uaac1\uaaf6\uabed\ufb1e\ufe20-\ufe2f\uff9e-\uff9f\u{101fd}\u{102e0}\u{10376}-\u{1037a}\u{10a0d}\u{10a0f}\u{10a38}-\u{10a3a}\u{10a3f}\u{10ae5}-\u{10ae6}\u{10d24}-\u{10d27}\u{10f46}-\u{10f50}\u{11046}\u{1107f}\u{110b9}-\u{110ba}\u{11100}-\u{11102}\u{11133}-\u{11134}\u{11173}\u{111c0}\u{111ca}\u{11235}-\u{11236}\u{112e9}-\u{112ea}\u{1133b}-\u{1133c}\u{1134d}\u{11366}-\u{1136c}\u{11370}-\u{11374}\u{11442}\u{11446}\u{1145e}\u{114c2}-\u{114c3}\u{115bf}-\u{115c0}\u{1163f}\u{116b6}-\u{116b7}\u{1172b}\u{11839}-\u{1183a}\u{119e0}\u{11a34}\u{11a47}\u{11a99}\u{11c3f}\u{11d42}\u{11d44}-\u{11d45}\u{11d97}\u{16af0}-\u{16af4}\u{16b30}-\u{16b36}\u{1bc9e}\u{1d165}-\u{1d169}\u{1d16d}-\u{1d172}\u{1d17b}-\u{1d182}\u{1d185}-\u{1d18b}\u{1d1aa}-\u{1d1ad}\u{1d242}-\u{1d244}\u{1e000}-\u{1e006}\u{1e008}-\u{1e018}\u{1e01b}-\u{1e021}\u{1e023}-\u{1e024}\u{1e026}-\u{1e02a}\u{1e130}-\u{1e136}\u{1e2ec}-\u{1e2ef}\u{1e8d0}-\u{1e8d6}\u{1e944}-\u{1e94a}]*/gsu;

    /*!
     * Copyright (c) Microsoft Corporation. All rights reserved.
     * Licensed under the MIT license.
     */
    class BiString {
      constructor(original, modified, alignment) {
        if (typeof original !== "string") {
          throw new TypeError("original was not a string");
        }

        this.original = original;

        if (modified === undefined) {
          modified = original;

          if (alignment === undefined) {
            alignment = Alignment.identity(original.length);
          }
        } else if (typeof modified === "string") {
          if (alignment === undefined) {
            alignment = new Alignment([[0, 0], [original.length, modified.length]]);
          }
        } else {
          throw new TypeError("modified was not a string");
        }

        this.modified = modified;

        if (!(alignment instanceof Alignment)) {
          throw new TypeError("alignment was not an Alignment");
        }

        const [ostart, oend] = alignment.originalBounds();

        if (ostart !== 0 || oend !== original.length) {
          throw new RangeError("Alignment incompatible with original string");
        }

        const [mstart, mend] = alignment.modifiedBounds();

        if (mstart !== 0 || mend !== modified.length) {
          throw new RangeError("Alignment incompatible with modified string");
        }

        this.alignment = alignment;
        this.length = this.modified.length;

        for (let i = 0; i < this.length; ++i) {
          this[i] = this.modified[i];
        }

        Object.freeze(this);
      }

      static from(str) {
        if (str instanceof BiString) {
          return str;
        } else {
          return new BiString(str);
        }
      }

      static infer(original, modified) {
        return heuristicInfer(original, modified);
      }

      [Symbol.iterator]() {
        return this.modified[Symbol.iterator]();
      }

      charAt(pos) {
        return this.modified.charAt(pos);
      }

      charCodeAt(pos) {
        return this.modified.charCodeAt(pos);
      }

      codePointAt(pos) {
        return this.modified.codePointAt(pos);
      }

      substring(start, end) {
        if (end === undefined) {
          end = this.length;
        }

        if (start > end) {
          [start, end] = [end, start];
        }

        start = Math.max(0, Math.min(start, this.length));
        end = Math.max(0, Math.min(end, this.length));
        return this.slice(start, end);
      }

      slice(start, end) {
        if (end === undefined) {
          end = this.length;
        }

        if (start < 0) {
          start += this.length;
        }

        if (end < 0) {
          end += this.length;
        }

        if (end < start) {
          end = start;
        }

        start = Math.max(0, Math.min(start, this.length));
        end = Math.max(0, Math.min(end, this.length));
        const alignment = this.alignment.sliceByModified(start, end);
        const modified = this.modified.slice(...alignment.modifiedBounds());
        const original = this.original.slice(...alignment.originalBounds());
        const [o0, m0] = alignment.values[0];
        return new BiString(original, modified, alignment.shift(-o0, -m0));
      }

      concat() {
        let original = this.original;
        let modified = this.modified;
        let alignment = this.alignment;

        for (var _len = arguments.length, others = new Array(_len), _key = 0; _key < _len; _key++) {
          others[_key] = arguments[_key];
        }

        for (const other of others) {
          const biother = BiString.from(other);
          alignment = alignment.concat(biother.alignment.shift(original.length, modified.length));
          original += biother.original;
          modified += biother.modified;
        }

        return new BiString(original, modified, alignment);
      }

      inverse() {
        return new BiString(this.modified, this.original, this.alignment.inverse());
      }

      equals(other) {
        return this.original === other.original && this.modified === other.modified && this.alignment.equals(other.alignment);
      }

      indexOf(searchValue, fromIndex) {
        return this.modified.indexOf(searchValue, fromIndex);
      }

      lastIndexOf(searchValue, fromIndex) {
        return this.modified.lastIndexOf(searchValue, fromIndex);
      }

      boundsOf(searchValue, fromIndex) {
        let start = this.indexOf(searchValue, fromIndex);

        if (start === -1) {
          return [-1, -1];
        } else {
          return [start, start + searchValue.length];
        }
      }

      lastBoundsOf(searchValue, fromIndex) {
        let start = this.lastIndexOf(searchValue, fromIndex);

        if (start === -1) {
          return [-1, -1];
        } else {
          return [start, start + searchValue.length];
        }
      }

      search(regexp) {
        return this.modified.search(regexp);
      }

      searchBounds(regexp) {
        const match = regexp.exec(this.modified);

        if (match === null) {
          return [-1, -1];
        } else {
          return [match.index, match.index + match[0].length];
        }
      }

      match(regexp) {
        return this.modified.match(regexp);
      }

      matchAll(regexp) {
        return this.modified.matchAll(regexp);
      }

      _replaceString(pattern, replacement) {
        const replacer = normalizeReplacer(replacement);
        const builder = new BiStringBuilder(this);

        while (!builder.isComplete) {
          const next = this.indexOf(pattern, builder.position);

          if (next < 0) {
            break;
          }

          builder.skip(next - builder.position);
          const match = [this.modified.slice(next, next + pattern.length)];
          match.index = next;
          match.input = this.modified;
          builder.replace(pattern.length, replacer(match));
        }

        builder.skipRest();
        return builder.build();
      }

      _replaceRegExp(pattern, replacement) {
        const builder = new BiStringBuilder(this);
        builder.replaceAll(pattern, replacement);
        return builder.build();
      }

      replace(pattern, replacement) {
        if (typeof pattern === "string") {
          return this._replaceString(pattern, replacement);
        } else {
          return this._replaceRegExp(pattern, replacement);
        }
      }

      trim() {
        return this.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g, "");
      }

      trimStart() {
        return this.replace(/^[\s\uFEFF\xA0]+/, "");
      }

      trimEnd() {
        return this.replace(/[\s\uFEFF\xA0]+$/, "");
      }

      padStart(targetLength) {
        let padString = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : " ";
        const padLength = targetLength - this.length;

        if (padLength <= 0) {
          return this;
        }

        if (padString.length < padLength) {
          padString += padString.repeat(targetLength / padString.length);
        }

        padString = padString.slice(0, padLength);
        return new BiString("", padString).concat(this);
      }

      padEnd(targetLength) {
        let padString = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : " ";
        const padLength = targetLength - this.length;

        if (padLength <= 0) {
          return this;
        }

        if (padString.length < padLength) {
          padString += padString.repeat(targetLength / padString.length);
        }

        padString = padString.slice(0, padLength);
        return this.concat(new BiString("", padString));
      }

      startsWith(searchString, position) {
        return this.modified.startsWith(searchString, position);
      }

      endsWith(searchString, position) {
        return this.modified.endsWith(searchString, position);
      }

      _splitString(pattern, limit) {
        if (limit === undefined) {
          limit = Infinity;
        }

        const result = [];

        for (let i = 0, j, k; i >= 0 && result.length < limit; i = k) {
          if (pattern.length === 0) {
            if (i + 1 < this.length) {
              j = k = i + 1;
            } else {
              j = k = -1;
            }
          } else {
            [j, k] = this.boundsOf(pattern, i);
          }

          if (j >= 0) {
            result.push(this.slice(i, j));
          } else {
            result.push(this.slice(i));
          }
        }

        return result;
      }

      _splitRegExp(pattern, limit) {
        pattern = cloneRegExp(pattern, "g", "y");

        if (limit === undefined) {
          limit = Infinity;
        }

        const result = [];
        let last = 0;

        for (const match of this.matchAll(pattern)) {
          if (result.length >= limit) {
            break;
          }

          const start = match.index;
          const end = start + match[0].length;
          result.push(this.slice(last, start));

          if (match.length > 1) {
            throw new Error("split() with capture groups is not supported");
          }

          last = end;
        }

        if (result.length < limit) {
          result.push(this.slice(last));
        }

        return result;
      }

      split(separator, limit) {
        if (separator === undefined) {
          return [this];
        } else if (typeof separator === "string") {
          return this._splitString(separator, limit);
        } else {
          return this._splitRegExp(separator, limit);
        }
      }

      join(items) {
        let [first, ...rest] = items;

        if (first === undefined) {
          return new BiString("");
        }

        first = BiString.from(first);
        rest = rest.flatMap(s => [this, s]);
        return first.concat(...rest);
      }

      static _normalFormRegex(form) {
        switch (form) {
          case "NFC":
            return NFC_CHUNK;

          case "NFD":
            return NFD_CHUNK;

          case "NFKC":
            return NFKC_CHUNK;

          case "NFKD":
            return NFKD_CHUNK;

          default:
            throw new RangeError(`Expected a normalization form (NFC, NFD, NFKC, NFKD); found ${form}`);
        }
      }

      normalize(form) {
        const regex = BiString._normalFormRegex(form);

        return this.replace(regex, m => {
          const result = m.normalize(form);

          if (result === m) {
            return new BiString(m);
          } else {
            return new BiString(m, result);
          }
        });
      }

      _isFinalSigmaAt(index) {
        if (this[index] !== "Σ") {
          return false;
        }

        for (let i = index + 1; i < this.length; ++i) {
          const cp = this.codePointAt(i);
          const c = String.fromCodePoint(cp);

          if (/\P{Case_Ignorable}/uy.test(c)) {
            if (/\p{Cased}/uy.test(c)) {
              return false;
            } else {
              break;
            }
          }

          if (cp > 0xFFFF) {
            ++i;
          }
        }

        for (let i = index; i-- > 0;) {
          let cp = this.charCodeAt(i);

          if (i > 0 && (cp & 0xFC00) == 0xDC00 && (this.charCodeAt(i - 1) & 0xFC00) == 0xD800) {
            --i;
            cp = this.codePointAt(i);
          }

          const c = String.fromCodePoint(cp);

          if (/\P{Case_Ignorable}/uy.test(c)) {
            if (/\p{Cased}/uy.test(c)) {
              return true;
            } else {
              break;
            }
          }
        }

        return false;
      }

      toLowerCase() {
        var _this = this;

        return this.replace(/\p{Changes_When_Lowercased}/gu, function (m) {
          var _ref;

          if (_this._isFinalSigmaAt((_ref = (arguments.length <= 1 ? 0 : arguments.length - 1) - 2 + 1, _ref < 1 || arguments.length <= _ref ? undefined : arguments[_ref]))) {
            return "ς";
          } else {
            return m.toLowerCase();
          }
        });
      }

      toUpperCase() {
        return this.replace(/\p{Changes_When_Uppercased}/gu, m => m.toUpperCase());
      }

    }

    /*!
     * Copyright (c) Microsoft Corporation. All rights reserved.
     * Licensed under the MIT license.
     */
    class Token {
      constructor(text, start, end) {
        this.text = BiString.from(text);
        this.start = start;
        this.end = end;
        Object.freeze(this);
      }

      static slice(text, start, end) {
        return new Token(BiString.from(text).slice(start, end), start, end);
      }

      get original() {
        return this.text.original;
      }

      get modified() {
        return this.text.modified;
      }

    }
    class Tokenization {
      constructor(text, tokens) {
        this.text = BiString.from(text);
        this.tokens = Object.freeze(Array.from(tokens));
        const alignment = [[0, 0]];
        this.tokens.forEach((token, i) => {
          alignment.push([token.start, i]);
          alignment.push([token.end, i + 1]);
        });
        alignment.push([this.text.length, this.tokens.length]);
        this.alignment = new Alignment(alignment);
        this.length = this.tokens.length;
        Object.freeze(this);
      }

      static infer(text, tokens) {
        text = BiString.from(text);
        const result = [];
        let start = 0,
            end;

        for (const token of tokens) {
          [start, end] = text.boundsOf(token, start);

          if (start < 0) {
            throw new Error(`Couldn't find the token "${token}" in the text`);
          }

          result.push(Token.slice(text, start, end));
          start = end;
        }

        return new Tokenization(text, result);
      }

      slice(start, end) {
        return new Tokenization(this.text, this.tokens.slice(start, end));
      }

      substring(start, end) {
        const [first, last] = this.textBounds(start, end);
        return this.text.substring(first, last);
      }

      textBounds(start, end) {
        if (start === undefined) {
          start = 0;
        }

        if (end === undefined) {
          end = this.length;
        }

        return this.alignment.originalBounds(start, end);
      }

      originalBounds(start, end) {
        return this.text.alignment.originalBounds(this.textBounds(start, end));
      }

      boundsForText(start, end) {
        return this.alignment.modifiedBounds(start, end);
      }

      boundsForOriginal(start, end) {
        const textBounds = this.text.alignment.modifiedBounds(start, end);
        return this.boundsForText(...textBounds);
      }

      sliceByText(start, end) {
        return this.slice(...this.boundsForText(start, end));
      }

      sliceByOriginal(start, end) {
        return this.slice(...this.boundsForOriginal(start, end));
      }

      snapTextBounds(start, end) {
        return this.textBounds(...this.boundsForText(start, end));
      }

      snapOriginalBounds(start, end) {
        return this.originalBounds(...this.boundsForOriginal(start, end));
      }

    }
    class RegExpTokenizer {
      constructor(pattern) {
        this._pattern = cloneRegExp(pattern, "g");
      }

      tokenize(text) {
        text = BiString.from(text);
        const tokens = [];

        for (const match of text.matchAll(this._pattern)) {
          const start = match.index;
          const end = start + match[0].length;
          tokens.push(Token.slice(text, start, end));
        }

        return new Tokenization(text, tokens);
      }

    }
    class SplittingTokenizer {
      constructor(pattern) {
        this._pattern = cloneRegExp(pattern, "g");
      }

      tokenize(text) {
        text = BiString.from(text);
        const tokens = [];
        let last = 0;

        for (const match of text.matchAll(this._pattern)) {
          const start = match.index;

          if (start > last) {
            tokens.push(Token.slice(text, last, start));
          }

          last = start + match[0].length;
        }

        if (text.length > last) {
          tokens.push(Token.slice(text, last, text.length));
        }

        return new Tokenization(text, tokens);
      }

    }

    exports.Alignment = Alignment;
    exports.BiString = BiString;
    exports.BiStringBuilder = BiStringBuilder;
    exports.RegExpTokenizer = RegExpTokenizer;
    exports.SplittingTokenizer = SplittingTokenizer;
    exports.Token = Token;
    exports.Tokenization = Tokenization;
    exports["default"] = BiString;

    Object.defineProperty(exports, '__esModule', { value: true });

}));
//# sourceMappingURL=index.browser.js.map
